@@ -78,6 +78,12 @@ function(x, control = list())
 {
     stopifnot(is.list(control))
 
+    if (any(unlist(lapply(control, is.function))))
+        warning("custom functions are ignored")
+
+    if (!is.null(control$tokenize) && !identical(control$tokenize, "Boost"))
+        warning("custom tokenizer is ignored")
+
     txt <- content(x)
 
     ## Conversion to lower case
@@ -123,13 +129,17 @@ function(x, control = list())
     ## significant overhead (as SnowballC does not export its internal C
     ## functions).
     ##
-    ## Stemming afterwards is still quite performant as we already have all
-    ## terms. However, there is some overhead involved as we need to recheck
-    ## local bounds and word lengths.
+    ## Stemming afterwards is still quite performant as we already have
+    ## all terms.  However, there is some overhead involved as we need
+    ## to recheck local bounds and word lengths.
     ## </NOTE>
     if (isTRUE(control$stemming)) {
-        stems <- as.factor(SnowballC::wordStem(m$dimnames$Terms,
-                                               meta(x, "language")))
+        stems <- SnowballC::wordStem(m$dimnames$Terms,
+                                     meta(x, "language"))
+        ## Do as.factor(stems) "by hand" for performance reasons.
+        uniqs <- sort(unique(stems))
+        stems <- match(stems, uniqs)
+        attributes(stems) <- list(levels = uniqs, class = "factor")
         m <- rollup(m, "Terms", stems)
 
         ## Recheck local bounds
